# Copyright 2011 Justin Santa Barbara
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from sqlalchemy import Column
from sqlalchemy import Boolean
from sqlalchemy import DateTime
from sqlalchemy import ForeignKey
from sqlalchemy import Integer
from sqlalchemy import MetaData
from sqlalchemy import String
from sqlalchemy import Table



class AddNotsoTablesMigration(object):
    def __init__(self, meta):
        self.meta = meta

    def list_dependent_tables(self):
        return ['instances']

    def get_create_tables(self):
        machines = Table('physical_machines', self.meta,
            Column('created_at', DateTime(timezone=False)),
            Column('updated_at', DateTime(timezone=False)),
            Column('deleted_at', DateTime(timezone=False)),
            Column('deleted', Boolean(create_constraint=True, name=None)),
            Column('id', Integer(), primary_key=True, nullable=False),
            Column('instance_id',
                   Integer(),
                   ForeignKey('instances.id'),
                   nullable=True),
            Column('network_config',
                   String(length=255, convert_unicode=False, assert_unicode=None,
                          unicode_error=None, _warn_on_bytestring=False))
            )

        return [machines]

    def do_upgrade(self):
        for table_name in self.list_dependent_tables():
            _table_obj = Table(table_name, self.meta, autoload=True)

        for table in self.get_create_tables():
            table.create()

    def do_downgrade(self):
        for table_name in self.list_dependent_tables():
            _table_obj = Table(table_name, self.meta, autoload=True)

        for _table in self.get_create_tables():
            # We don't want to drop these tables, because that loses data
            #table.drop()
            pass


def upgrade(migrate_engine):
    # Upgrade operations go here. Don't create your own engine;
    # bind migrate_engine to your metadata
    meta = MetaData()
    meta.bind = migrate_engine

    migration = AddNotsoTablesMigration(meta)
    migration.do_upgrade()

def downgrade(migrate_engine):
    # Upgrade operations go here. Don't create your own engine;
    # bind migrate_engine to your metadata
    meta = MetaData()
    meta.bind = migrate_engine

    migration = AddNotsoTablesMigration(meta)
    migration.do_downgrade()
